Index: src/wp-admin/post.php
===================================================================
--- src/wp-admin/post.php	(revision 57110)
+++ src/wp-admin/post.php	(working copy)
@@ -28,9 +28,10 @@
 $post_ID = $post_id;
 
 /**
  * @global string  $post_type
  * @global object  $post_type_object
  * @global WP_Post $post             Global post object.
  */
 global $post_type, $post_type_object, $post;
 
@@ -39,6 +40,7 @@
 }
 
 if ( $post ) {
+	$wp_query->post   = $post;
 	$post_type        = $post->post_type;
 	$post_type_object = get_post_type_object( $post_type );
 }
@@ -28,9 +28,10 @@
 
 /**
- * @global string  $post_type
- * @global object  $post_type_object
- * @global WP_Post $post             Global post object.
+ * @global string   $post_type
+ * @global object   $post_type_object
+ * @global WP_Post  $post            Global post object.
+ * @global WP_Query $wp_query        Global query object.
  */
 global $post_type, $post_type_object, $post;
